# Heavy Uploader
Python script for uploading and managing content on the Heavy Cloud Service (https://enzienaudio.com)

### Installing

`$ pip install hv-uploader`

### Upgrading

`$ pip install hv-uploader -U`

(Note: this will also update any dependencies)
